@@ -71,6 +71,7 @@ impl Icons {
     const LANG_STYLUS: char     = '\u{e600}';  // 
     const LANG_TEX: char        = '\u{e69b}';  // 
     const LANG_TYPESCRIPT: char = '\u{e628}';  // 
+    const LANG_V: char          = '\u{e6ac}';  // 
     const LIBRARY: char         = '\u{eb9c}';  // 
     const LICENSE: char         = '\u{f02d}';  // 
     const LOCK: char            = '\u{f023}';  // 
@@ -232,6 +233,8 @@ const FILENAME_ICONS: Map<&'static str, char> = phf_map! {
     "csh.logout"          => Icons::SHELL,          // 󱆃
     "docker-compose.yml"  => Icons::DOCKER,         // 
     "Dockerfile"          => Icons::DOCKER,         // 
+    "dune"                => Icons::LANG_OCAML,     // 
+    "dune-project"        => Icons::WRENCH,          // 
     "Earthfile"           => '\u{f0ac}',            // 
     "environment"         => Icons::CONFIG,         // 
     "GNUmakefile"         => Icons::MAKE,           // 
@@ -599,6 +602,7 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "ppt"            => Icons::SLIDE,            // 
     "pptx"           => Icons::SLIDE,            // 
     "properties"     => Icons::JSON,             // 
+    "prql"           => Icons::DATABASE,         // 
     "ps"             => Icons::VECTOR,           // 󰕙
     "ps1"            => Icons::POWERSHELL,       // 
     "psd"            => '\u{e7b8}',              // 
@@ -709,7 +713,7 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "tzo"            => Icons::COMPRESSED,       // 
     "unity"          => Icons::UNITY,            // 
     "unity3d"        => Icons::UNITY,            // 
-    "v"              => '\u{e6ac}',              // 
+    "v"              => Icons::LANG_V,           // 
     "vdi"            => Icons::DISK_IMAGE,       // 
     "vhd"            => Icons::DISK_IMAGE,       // 
     "video"          => Icons::VIDEO,            // 
