@@ -2,6 +2,7 @@ use ansiterm::Style;
 
 use crate::fs::File;
 use crate::info::filetype::FileType;
+use crate::output::color_scale::ColorScaleOptions;
 use crate::output::file_name::Colours as FileNameColours;
 use crate::output::render;
 
@@ -17,7 +18,7 @@ mod default_theme;
 pub struct Options {
     pub use_colours: UseColours,
 
-    pub colour_scale: ColourScale,
+    pub colour_scale: ColorScaleOptions,
 
     pub definitions: Definitions,
 }
@@ -41,12 +42,6 @@ pub enum UseColours {
     Never,
 }
 
-#[derive(PartialEq, Eq, Debug, Copy, Clone)]
-pub enum ColourScale {
-    Fixed,
-    Gradient,
-}
-
 #[derive(PartialEq, Eq, Debug, Default)]
 pub struct Definitions {
     pub ls: Option<String>,
